@@ -1,5 +1,5 @@
 package Whelk::Schema::Definition::Object;
-$Whelk::Schema::Definition::Object::VERSION = '1.00';
+$Whelk::Schema::Definition::Object::VERSION = '1.01';
 use Whelk::StrictBase 'Whelk::Schema::Definition';
 
 attr '?properties' => undef;
@@ -78,6 +78,8 @@ sub inhale
 {
 	my ($self, $value) = @_;
 
+	return undef if $self->_valid_nullable($value);
+
 	if (ref $value eq 'HASH') {
 		my $properties = $self->properties;
 		if ($properties) {
@@ -93,7 +95,7 @@ sub inhale
 				return "object[$key]->$inhaled" if defined $inhaled;
 			}
 
-			if ($self->strict && keys %$value > keys %$properties) {
+			if ($self->strict) {
 				foreach my $key (keys %$value) {
 					next if exists $properties->{$key};
 					return "object[$key]->redundant";
@@ -111,6 +113,8 @@ sub exhale
 {
 	my ($self, $value) = @_;
 
+	return undef if $self->_valid_nullable($value);
+
 	my $properties = $self->properties;
 	return $value unless $properties;
 
