@@ -12,6 +12,15 @@ sub api
 			type => 'integer',
 			description => 'Internal ID',
 			example => 1337,
+			rules => [
+				{
+					openapi => {
+						minimum => 1,
+					},
+					hint => '(>=1)',
+					code => sub { shift() >= 1 },
+				},
+			],
 		}
 	);
 
@@ -25,6 +34,11 @@ sub api
 					description => 'Name of the entity',
 					example => "John's entity",
 				},
+				value => {
+					type => 'integer',
+					nullable => !!1,
+					default => undef,
+				},
 			}
 		}
 	);
